v0.3.0 (2023-09-12)
-------------------
- Drop support for Python 3.6
- Support Python 3.11
- Remove the function-based API (deprecated in v0.2.0)

v0.2.1 (2021-10-05)
-------------------
- Support Python 3.10

v0.2.0 (2021-06-30)
-------------------
- The function-based API has been replaced by a class-based API.  The functions
  themselves are now deprecated and will be removed in a future version.

v0.1.0 (2021-06-24)
-------------------
Initial release
